@@ -1,7 +1,8 @@
 from mpcd.mpcd import PointCloud
 from mpcd.visualizer import PointCloudVisualizer
+from mpcd.grouper import group
 
 
 
-__all__ = ['PointCloud','PointCloudVisualizer']
+__all__ = ['PointCloud','PointCloudVisualizer', 'group']
 
