@@ -371,7 +371,7 @@ class PointCloud:
     def save_ascii(self, fname):
         self.save_pcd(fname, "ascii")
 
-    def draw_pcloud(
+    def draw_bev(
         self,
         color="gray",
         r=0,
@@ -395,6 +395,26 @@ class PointCloud:
         )
         return draw
 
+    @staticmethod
+    def draw_bev_overlay(
+        pc_tuple,
+        draw_distance_marker=True,
+        draw_orin=True,
+        show=True,
+        auto_rot=True,
+        save=False,
+        save_path=None):
+        return PointCloud.vis.draw_pc_overlay(
+            pc_tuple,
+            draw_distance_marker,
+            draw_orin,
+            show,
+            auto_rot,
+            save,
+            save_path,
+        )
+
+
     def to_ndarray(self, fields=None):
         if not fields:
             fields = self.fields
@@ -476,6 +496,9 @@ class PointCloud:
 
         field = condition_str.split(operator)[0]
         value = condition_str.split(operator)[1]
+        if field+logic+value!=condition_str:
+            raise ValueError('condition incorrect')
+        assert field and logic and value, 'condition incorrect'
         return field, logic, value
 
     def filter_by_condition(self, conditions):
@@ -490,6 +513,7 @@ class PointCloud:
         self._adjust_field()
         return self
 
+
     def _adjust_field(self):
         self.points = self.pc_data.shape[0]
         self.width = self.points
